@@ -18,6 +18,8 @@ ManageData <- function(cols, vars, parent=NULL) {
   SetVarId <- function(idx=NULL) {
     if (is.null(idx))
       idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    if (length(idx) == 0)
+      return()
 
     # Save name
 
@@ -26,21 +28,14 @@ ManageData <- function(cols, vars, parent=NULL) {
       nam <- NULL
     cols[[idx]]$name <<- nam
 
-    # Save units
-
-    unt <- tclvalue(unit.var)
-    if (unt == "")
-      unt <- NULL
-    cols[[idx]]$unit <<- unt
-
     # Insure content for id
 
-    if (is.null(nam) & is.null(unt))
+    if (is.null(nam))
       cols[[idx]]$name <<- "Unknown"
 
     # Account for duplicate ids
 
-    new.id <- paste(c(nam, unt), collapse=", ")
+    new.id <- nam
     old.id <- cols[[idx]]$id
     old.ids <- sapply(cols, function(i) i$id)
 
@@ -66,10 +61,10 @@ ManageData <- function(cols, vars, parent=NULL) {
 
       new.fun <- cols[[idx]]$fun
       if (!identical(old.fun, new.fun)) {
-        tkconfigure(frame2.txt.5.2, state="normal")
-        tcl(frame2.txt.5.2, "delete", '1.0', 'end')
-        tkinsert(frame2.txt.5.2, "end", new.fun)
-        tkconfigure(frame2.txt.5.2, state="disabled")
+        tkconfigure(frame2.txt.4.2, state="normal")
+        tcl(frame2.txt.4.2, "delete", "1.0", "end")
+        tkinsert(frame2.txt.4.2, "end", new.fun)
+        tkconfigure(frame2.txt.4.2, state="disabled")
       }
       
       query.fun <- Data("query.fun")
@@ -83,18 +78,10 @@ ManageData <- function(cols, vars, parent=NULL) {
   # Save notebook content
 
   SaveNb <- function() {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
     if (length(idx) == 0)
       return()
 
-    # Save units
-
-    old.unt <- cols[[idx]]$unit
-    new.unt <- as.character(tclvalue(unit.var))
-    if (new.unt == "")
-      new.unt <- NULL
-    cols[[idx]]$unit <<- new.unt
-
     # Save format
 
     old.fmt <- cols[[idx]]$format
@@ -106,7 +93,7 @@ ManageData <- function(cols, vars, parent=NULL) {
     # Save function
 
     old.fun <- cols[[idx]]$fun
-    new.fun <- as.character(tclvalue(tkget(frame2.txt.5.2, '1.0', 'end-1c')))
+    new.fun <- as.character(tclvalue(tkget(frame2.txt.4.2, "1.0", "end-1c")))
     cols[[idx]]$fun <<- new.fun
 
     # Save summary
@@ -122,24 +109,16 @@ ManageData <- function(cols, vars, parent=NULL) {
       cols[[idx]]$summary <<- SummarizeData(cols[[idx]]$summary, fmt=new.fmt)
     }
 
-    # Save class
-
-    if (!is.null(cols[[idx]]$summary))
-      cols[[idx]]$class <<- cols[[idx]]$summary$Class
-
     # Save name
-
     SetVarId(idx)
   }
 
   # Update notebook content
 
   UpdateNb <- function() {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
-    if (length(idx) == 0) {
-      SaveNewVar()
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
+    if (length(idx) == 0) 
       return()
-    }
 
     # Update name
 
@@ -148,44 +127,49 @@ ManageData <- function(cols, vars, parent=NULL) {
       saved.name <- ""
     tclvalue(name.var) <- saved.name
 
-    # Update units
+    # Update class
 
-    saved.unit <- cols[[idx]]$unit
-    if (is.null(saved.unit))
-      saved.unit <- ""
-    tclvalue(unit.var) <- saved.unit
+    tkconfigure(frame2.ent.3.2, state="normal")
+    saved.class <- cols[[idx]]$class
+    tclvalue(class.var) <- saved.class
+    tkconfigure(frame2.ent.3.2, state="readonly")
 
     # Update format
 
-    tkconfigure(frame2.ent.3.2, state="normal")
-    saved.fmt <- cols[[idx]]$format
-    if (is.null(saved.fmt))
-      saved.fmt <- ""
+    saved.fmt <- cols[[idx]]$format   
+    if (is.null(saved.fmt) || saved.fmt == "") {
+      if (saved.class %in% c("character", "logical")) {
+        saved.fmt <- "%s"
+      } else if (saved.class == "numeric") {
+        saved.fmt <- "%f"
+      } else if (saved.class == "integer") {
+        saved.fmt <- "%d"
+      } else if (saved.class == "POSIXct") {
+        saved.fmt <- "%d/%m/%Y %H:%M:%OS"
+      } else {
+        saved.fmt <- ""
+      }
+    }
+    tkconfigure(frame2.ent.2.2, state="normal")
     tclvalue(fmt.var) <- saved.fmt
-    tkconfigure(frame2.ent.3.2, state="readonly")
-
-    # Update class
-
-    tkconfigure(frame2.ent.4.2, state="normal")
-    tclvalue(class.var) <- cols[[idx]]$class
-    tkconfigure(frame2.ent.4.2, state="readonly")
+    tkconfigure(frame2.ent.2.2, state="readonly")
 
     # Update function
 
-    tkconfigure(frame2.txt.5.2, state="normal")
-    tcl(frame2.txt.5.2, "delete", '1.0', 'end')
-    tkinsert(frame2.txt.5.2, "end", cols[[idx]]$fun)
-    tkconfigure(frame2.txt.5.2, state="disabled")
+    tkconfigure(frame2.txt.4.2, state="normal")
+    tcl(frame2.txt.4.2, "delete", "1.0", "end")
+    tkinsert(frame2.txt.4.2, "end", cols[[idx]]$fun)
+    tkconfigure(frame2.txt.4.2, state="disabled")
 
     s <- "disabled"
     if (is.null(cols[[idx]]$index))
       s <- "normal"
-    tkconfigure(frame2.but.5.3, state=s)
+    tkconfigure(frame2.but.4.3, state=s)
 
     # Update summary
 
     tkconfigure(frame3.txt, state="normal")
-    tcl(frame3.txt, "delete", '1.0', 'end')
+    tcl(frame3.txt, "delete", "1.0", "end")
 
     sum.str <- cols[[idx]]$summary$String
     if (!is.null(sum.str))
@@ -197,49 +181,28 @@ ManageData <- function(cols, vars, parent=NULL) {
   # Account for change in notebook tab
 
   ChangeTab <- function() {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
     if (length(idx) == 0)
       return()
 
     SaveNb()
     UpdateNb()
 
-    tabid <- tclvalue(tcl(nb, 'select'))
+    tabid <- tclvalue(tcl(nb, "select"))
 
-    # Arrive at variable tab
+    # Arrive at tab
 
     if (tabid == frame2$ID) {
       tkfocus(frame2)
-
-    # Arrive at summary tab
-
     } else if (tabid == frame3$ID) {
       tkfocus(frame3)
     }
   }
 
-  # Save new variable
-
-  SaveNewVar <- function() {
-    SaveNb()
-    id <- "New Variable"
-    tcl("lappend", list.var, id)
-    n <- length(cols)
-    tkselection.clear(frame1.lst, 0, n)
-    tkselection.set(frame1.lst, n, n)
-    tkyview(frame1.lst, n - 1L)
-    cols[[n + 1]] <<- list(name=id, class="logical", fun="")
-    UpdateNb()
-    SetVarId()
-
-    if (n > 0)
-      CallEditFunction()
-  }
-
   # Delete existing variable
 
   DeleteVar <- function() {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
     if (length(idx) == 0)
       return()
 
@@ -248,56 +211,108 @@ ManageData <- function(cols, vars, parent=NULL) {
     dependent.vars <- funs.with.var[!funs.with.var %in% idx]
 
     if (length(dependent.vars) > 0) {
-      msg <- paste("Removal of this variable first requires that the",
-                   "following dependent variable(s) be removed:", sep="\n")
-      detail <- paste(sapply(cols, function(i) i$id)[dependent.vars],
-                      collapse="\n")
-      tkmessageBox(icon="info", message=msg, detail=detail,
-                   title="Prevented Deletion", type="ok", parent=tt)
+      ids <- vapply(cols, function(i) i$id, "")[dependent.vars]
+      msg <- paste("Variables dependent on variable \"", cols[[idx]]$id, 
+                   "\" include:\n\n  ", paste(ids, collapse=", "),
+                   "\n\nThese variables must first be removed before this ", 
+                   "operation can be completed.", sep="")
+      tkmessageBox(icon="error", message=msg, title="Deletion Prevented", 
+                   type="ok", parent=tt)
       return()
     }
+    if (!is.null(cols[[idx]]$index)) {
+      msg <- paste("Variable \"", cols[[idx]]$id, 
+                   "\" corresponds with imported data.\n\n",
+                   "Are you sure you want to remove it?", sep="")
+      ans <- tkmessageBox(icon="question", message=msg, title="Question", 
+                          type="okcancel", parent=tt)
+      if (as.character(ans) == "cancel") 
+        return()
+    }
 
-    tclvalue(list.var) <- tcl("lreplace", tclvalue(list.var), idx - 1, idx - 1)
-
+    tclvalue(list.var) <- tcl("lreplace", tclvalue(list.var), 
+                              idx - 1L, idx - 1L)
+    
     cols <<- cols[-idx]
     vars <<- vars[!vars %in% idx]
+    
+    if (length(cols) == 0)
+      cols <<- NULL
+    if (length(vars) == 0)
+      vars <<- NULL
+    
     for (i in seq(along=vars)) {
       if (vars[[i]] > idx)
-        vars[[i]] <<- vars[[i]] - 1
+        vars[[i]][1] <<- vars[[i]] - 1
     }
 
     tkselection.clear(frame1.lst, 0, "end")
-    if (idx > length(cols))
-      tkselection.set(frame1.lst, idx - 2)
-    else
-      tkselection.set(frame1.lst, idx - 1)
+    
+    n <- length(cols)
+    if (n > 0) {
+      if (idx > n)
+        tkselection.set(frame1.lst, idx - 2)
+      else
+        tkselection.set(frame1.lst, idx - 1)
+      UpdateNb()
+    } else {
+      tclvalue(name.var) <- ""
+      tclvalue(class.var) <- ""
+      tclvalue(fmt.var) <- ""
+      tkconfigure(frame2.txt.4.2, state="normal")
+      tcl(frame2.txt.4.2, "delete", "1.0", "end")
+      tkconfigure(frame2.txt.4.2, state="disabled")
+      tkconfigure(frame3.txt, state="normal")
+      tcl(frame3.txt, "delete", "1.0", "end")
+      tkconfigure(frame3.txt, state="disabled")
+    }
+  }
+
+  # Save new variable
+
+  SaveNewVar <- function() {
+    SaveNb()
+    
+    new.name <- "New Variable"
+    idx <- length(cols) + 1L
+    
+    cols[[idx]] <- list(id="", class="")
+    value.length <- cols[[1]]$summary$Count
+    f <- EditFunction(cols, index=idx, value.length=value.length, parent=tt)
+    
+    if (is.null(f$fun) || f$fun == "") 
+      return()
+    
+    cols[[idx]] <<- list(id="", name="New Variable", class=f$class, fun=f$fun, 
+                         sample=f$sample, summary=f$summary)
+    
+    tcl("lappend", list.var, new.name)
+    tkselection.clear(frame1.lst, 0, "end")
+    tkselection.set(frame1.lst, idx - 1L, idx - 1L)
+    tkyview(frame1.lst, idx - 1L)
+    
     UpdateNb()
+    SetVarId(idx)
   }
 
   # Edit a variables function formula
 
   CallEditFunction <- function() {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    SaveNb()
+    
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
     if (length(idx) == 0)
       return()
     
-    if(is.null(Data("data.raw"))) {
-      n <- NULL
-    } else {
-      n <- nrow(Data("data.raw"))
-    }
+    n <- cols[[1]]$summary$Count
+    f <- EditFunction(cols, index=idx, value.length=n, parent=tt)
     
-    new.fun <- EditFunction(cols, index=idx, value.length=n, parent=tt)
-    
-    if (is.null(new.fun)) {
-      if (cols[[idx]]$fun == "")
-        DeleteVar()
+    if (is.null(f$fun)) 
       return()
-    }
-    
-    if (new.fun == "") {
-      msg <- paste("Nothing is defined for the function",
-                   "and the variable will be deleted.")
+    if (f$fun == "") {
+      msg <- paste("Nothing has been defined for this function; therefore,\n",
+                   "the variable '", cols[[idx]]$name, "' will be removed.",
+                   sep="")
       ans <- as.character(tkmessageBox(icon="question", message=msg,
                                        title="Warning", type="okcancel",
                                        parent=tt))
@@ -305,20 +320,21 @@ ManageData <- function(cols, vars, parent=NULL) {
         DeleteVar()
       return()
     }
-
-    tkconfigure(frame2.txt.5.2, state="normal")
-    tcl(frame2.txt.5.2, "delete", '1.0', 'end')
-    tkinsert(frame2.txt.5.2, "end", new.fun)
-    tkconfigure(frame2.txt.5.2, state="disabled")
-
-    SaveNb()
+    
+    cols[[idx]]$fun     <<- f$fun
+    cols[[idx]]$class   <<- f$class
+    cols[[idx]]$summary <<- f$summary
+    cols[[idx]]$sample  <<- f$sample
+    
     UpdateNb()
   }
 
   # Edit format
 
   CallFormat <- function() {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
+    if (length(idx) == 0)
+      return()
 
     sample.value <- cols[[idx]]$sample
 
@@ -338,7 +354,7 @@ ManageData <- function(cols, vars, parent=NULL) {
   # Arrange variables in listbox
 
   Arrange <- function(type) {
-    idx <- as.integer(tkcurselection(frame1.lst)) + 1
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
     if (length(idx) == 0)
       return()
 
@@ -359,19 +375,22 @@ ManageData <- function(cols, vars, parent=NULL) {
       if (idx == 1)
         return()
       new.idxs <- 1:n
-      new.idxs[c(idx - 1, idx)] <- c(idx, idx - 1)
-      new.idx <- idx - 1
+      new.idxs[c(idx - 1L, idx)] <- c(idx, idx - 1L)
+      new.idx <- idx - 1L
     } else if (type == "forward") {
       if (idx == n)
         return()
       new.idxs <- 1:n
-      new.idxs[c(idx, idx + 1)] <- c(idx + 1, idx)
-      new.idx <- idx + 1
+      new.idxs[c(idx, idx + 1L)] <- c(idx + 1L, idx)
+      new.idx <- idx + 1L
     }
 
     cols <<- cols[new.idxs]
-    vars <<- lapply(vars, function(i) idxs[new.idxs %in% i[1]])
-
+    
+    for (i in seq(along=vars)) {
+      vars[[i]][1] <<- idxs[new.idxs %in% vars[[i]][1]]
+    }
+    
     ids <- sapply(cols, function(i) i$id)
 
     for (i in 1:n)
@@ -384,24 +403,32 @@ ManageData <- function(cols, vars, parent=NULL) {
 
   # View data for selected variable
 
-  CallViewData <- function() {
+  CallViewData <- function(type="dataframe") {
+    idx <- as.integer(tkcurselection(frame1.lst)) + 1L
+    if (length(idx) == 0)
+      return()
+    
     tkconfigure(tt, cursor="watch")
     SaveNb()
     
-    nams <- sapply(cols, function(i) ifelse(is.null(i$name), NA, i$name))
-    unts <- sapply(cols, function(i) ifelse(is.null(i$unit), NA, i$unit))
-    fmts <- sapply(cols, function(i) ifelse(is.null(i$format), NA, i$format))
-    funs <- sapply(cols, function(i) ifelse(is.null(i$fun), NA, i$fun))
-    d <- lapply(1:length(cols), function(i) EvalFunction(funs[i], cols))
+    if (type == "data")
+      idxs <- idx
+    else
+      idxs <- 1:length(cols)
     
-    ViewData(as.data.frame(d), nams, unts, fmts, parent=tt)
+    funs <- sapply(cols, function(i) ifelse(is.null(i$fun), NA, i$fun))
+    nams <- sapply(cols, function(i) ifelse(is.null(i$name), NA, i$name))
+    fmts <- sapply(cols, function(i) ifelse(is.null(i$format), NA, i$format))
+    d <- lapply(idxs, function(i) EvalFunction(funs[i], cols))
+    
+    ViewData(as.data.frame(d), nams[idxs], fmts[idxs], parent=tt)
     tkconfigure(tt, cursor="arrow")
     tkfocus(tt)
   }
   
   # Build historgram
   
-  CallBuildHistogram <- function(check.variable=FALSE) {
+  CallBuildHistogram <- function() {
     SaveNb()
     idx <- as.integer(tkcurselection(frame1.lst)) + 1L
     if (length(idx) == 0)
@@ -410,8 +437,8 @@ ManageData <- function(cols, vars, parent=NULL) {
     cont.classes <- c("integer", "numeric")
     idxs <- which(sapply(cols, function(i) i$class) %in% cont.classes)
     
-    if (length(idxs) == 0 | (check.variable & !idx %in% idxs)) {
-      msg <- paste("Histogram may only be built for continous variables;",
+    if (length(idxs) == 0) {
+      msg <- paste("A histogram may only be built for continous variables;",
                    "that is, variables of class \"numeric\" or \"integer\".")
       tkmessageBox(icon="info", message=msg, title="Histogram", type="ok", 
                    parent=tt)
@@ -421,6 +448,7 @@ ManageData <- function(cols, vars, parent=NULL) {
     ids <- sapply(cols, function(i) ifelse(is.null(i$id), NA, i$id))
     funs <- sapply(cols, function(i) ifelse(is.null(i$fun), NA, i$fun))
     d <- sapply(idxs, function(i) EvalFunction(funs[i], cols))
+    d <- as.data.frame(d)
     
     var.names <- ids[idxs]
     if (idx %in% idxs)
@@ -428,8 +456,7 @@ ManageData <- function(cols, vars, parent=NULL) {
     else
       var.default <- var.names[1]
     
-    BuildHistogram(as.data.frame(d), var.names=var.names, 
-                   var.default=var.default, parent=tt)
+    BuildHistogram(d, var.names=var.names, var.default=var.default, parent=tt)
     tkfocus(tt)
   }
 
@@ -441,20 +468,19 @@ ManageData <- function(cols, vars, parent=NULL) {
   rtn <- NULL
 
   old.cols <- cols
-  ids <- sapply(cols, function(i) i$id)
+  ids <- vapply(cols, function(i) i$id, "")
 
   w <- 300
   h <- 50
 
   # Assign the variables linked to Tk widgets
 
-  list.var <- tclVar()
-  for (i in ids)
-    tcl("lappend", list.var, i)
+  list.var <- tclVar() 
+  for (i in seq(along=ids))
+    tcl("lappend", list.var, ids[i])
 
-  name.var <- tclVar()
-  unit.var <- tclVar()
-  fmt.var  <- tclVar()
+  name.var  <- tclVar()
+  fmt.var   <- tclVar()
   class.var <- tclVar()
 
   tt.done.var <- tclVar(0)
@@ -478,74 +504,80 @@ ManageData <- function(cols, vars, parent=NULL) {
 
   menu.edit <- tkmenu(tt, tearoff=0, relief="flat")
   tkadd(top.menu, "cascade", label="Edit", menu=menu.edit, underline=0)
-  tkadd(menu.edit, "command", label="New", accelerator="Ctrl+N",
+  tkadd(menu.edit, "command", label="New\u2026", accelerator="Ctrl+N",
         command=SaveNewVar)
   tkadd(menu.edit, "command", label="Delete", command=DeleteVar)
   tkadd(menu.edit, "separator")
-  tkadd(menu.edit, "command", label="Histogram", 
-        command=function() CallBuildHistogram(FALSE))
-  tkadd(menu.edit, "separator")
-  tkadd(menu.edit, "command", label="View data table", command=CallViewData)
+  tkadd(menu.edit, "command", label="View data", 
+        command=function() CallViewData("data"))
+  tkadd(menu.edit, "command", label="View data frame", 
+        command=function() CallViewData())
 
   menu.arrange <- tkmenu(tt, tearoff=0)
   tkadd(top.menu, "cascade", label="Arrange", menu=menu.arrange, underline=0)
   tkadd(menu.arrange, "command", label="Send to top",
-        accelerator="Shift+Ctrl+[", command=function() {Arrange("back")})
+        accelerator="Shift+Ctrl+[", command=function() Arrange("back"))
   tkadd(menu.arrange, "command", label="Send upward",
-        accelerator="Ctrl+[", command=function() {Arrange("backward")})
+        accelerator="Ctrl+[", command=function() Arrange("backward"))
   tkadd(menu.arrange, "command", label="Bring downward",
-        accelerator="Ctrl+]", command=function() {Arrange("forward")})
+        accelerator="Ctrl+]", command=function() Arrange("forward"))
   tkadd(menu.arrange, "command", label="Bring to bottom",
-        accelerator="Shift+Ctrl+]", command=function() {Arrange("front")})
-
+        accelerator="Shift+Ctrl+]", command=function() Arrange("front"))
+  
+  menu.graph <- tkmenu(tt, tearoff=0)
+  tkadd(top.menu, "cascade", label="Graph", menu=menu.graph, underline=0)
+  tkadd(menu.graph, "command", label="Histogram\u2026", 
+        command=CallBuildHistogram)
+  
   tkconfigure(tt, menu=top.menu)
 
   # Frame 0, ok and cancel buttons, and size grip
 
   frame0 <- ttkframe(tt, relief="flat")
-
-  frame0.but.1 <- ttkbutton(frame0, width=2, image=GetBitmapImage("up"),
-                            command=function() Arrange("backward"))
-  frame0.but.2 <- ttkbutton(frame0, width=2, image=GetBitmapImage("top"),
+  frame0.but.1 <- ttkbutton(frame0, width=2, image=GetBitmapImage("top"),
                             command=function() Arrange("back"))
-  frame0.but.3 <- ttkbutton(frame0, width=2, image=GetBitmapImage("bottom"),
-                            command=function() Arrange("front"))
-  frame0.but.4 <- ttkbutton(frame0, width=2, image=GetBitmapImage("down"),
+  frame0.but.2 <- ttkbutton(frame0, width=2, image=GetBitmapImage("up"),
+                            command=function() Arrange("backward"))
+  frame0.but.3 <- ttkbutton(frame0, width=2, image=GetBitmapImage("down"),
                             command=function() Arrange("forward"))
-  
-  frame0.but.5 <- ttkbutton(frame0, width=2, image=GetBitmapImage("histogram"),
-                            command=function() CallBuildHistogram(TRUE))
+  frame0.but.4 <- ttkbutton(frame0, width=2, image=GetBitmapImage("bottom"),
+                            command=function() Arrange("front"))
+  frame0.but.5 <- ttkbutton(frame0, width=2, image=GetBitmapImage("view"),
+                            command=function() CallViewData("data"))
   frame0.but.6 <- ttkbutton(frame0, width=2, image=GetBitmapImage("plus"),
                             command=SaveNewVar)
-  
   frame0.but.7 <- ttkbutton(frame0, width=2, image=GetBitmapImage("delete"),
                             command=DeleteVar)
-  
-  frame0.but.9  <- ttkbutton(frame0, width=12, text="OK",
-                             command=function() SaveChanges("ok"))
-  frame0.but.10 <- ttkbutton(frame0, width=12, text="Apply",
+                            
+  frame0.but.9 <- ttkbutton(frame0, width=12, text="OK",
+                            command=function() SaveChanges("ok"))
+  frame0.but.10 <- ttkbutton(frame0, width=12, text="Cancel",
+                             command=function() tclvalue(tt.done.var) <- 1)
+  frame0.but.11 <- ttkbutton(frame0, width=12, text="Apply",
                              command=function() SaveChanges("apply"))
-  frame0.but.11 <- ttkbutton(frame0, width=12, text="Cancel",
-                            command=function() tclvalue(tt.done.var) <- 1)
-
+  frame0.but.12 <- ttkbutton(frame0, width=12, text="Help",
+                             command=function() {
+                               print(help("ManageData", package="RSurvey", 
+                                          verbose=FALSE))
+                             })
   frame0.grp.12 <- ttksizegrip(frame0)
 
-  tkgrid(frame0.but.1, frame0.but.2, frame0.but.3, frame0.but.4, frame0.but.5,
+  tkgrid(frame0.but.1, frame0.but.2, frame0.but.3, frame0.but.4, frame0.but.5, 
          frame0.but.6, frame0.but.7, "x", frame0.but.9, frame0.but.10, 
-         frame0.but.11, frame0.grp.12)
+         frame0.but.11, frame0.but.12, frame0.grp.12)
 
   tkgrid.columnconfigure(frame0, 7, weight=1)
 
-  tkgrid.configure(frame0.but.1, frame0.but.2, frame0.but.3, frame0.but.4,
+  tkgrid.configure(frame0.but.1, frame0.but.2, frame0.but.3, frame0.but.4, 
                    frame0.but.5, frame0.but.6, frame0.but.7, sticky="n", 
                    padx=c(0, 2), pady=c(0, 0))
   tkgrid.configure(frame0.but.1, padx=c(10, 2))
-  tkgrid.configure(frame0.but.9, frame0.but.10, frame0.but.11,
+  tkgrid.configure(frame0.but.9, frame0.but.10, frame0.but.11, frame0.but.12,
                    padx=c(0, 4), pady=c(15, 10))
-  tkgrid.configure(frame0.but.11, columnspan=2, padx=c(0, 10))
+  tkgrid.configure(frame0.but.12, columnspan=2, padx=c(0, 10))
   tkgrid.configure(frame0.grp.12, sticky="se")
 
-  tkraise(frame0.but.11, frame0.grp.12)
+  tkraise(frame0.but.12, frame0.grp.12)
 
   tkpack(frame0, fill="x", side="bottom", anchor="e")
 
@@ -582,49 +614,44 @@ ManageData <- function(cols, vars, parent=NULL) {
   tkadd(nb, frame2, text="   Variable   ")
 
   frame2.lab.1.1 <- ttklabel(frame2, text="Name")
-  frame2.lab.2.1 <- ttklabel(frame2, text="Unit")
-  frame2.lab.3.1 <- ttklabel(frame2, text="Format")
-  frame2.lab.4.1 <- ttklabel(frame2, text="Class")
-  frame2.lab.5.1 <- ttklabel(frame2, text="Function")
+  frame2.lab.2.1 <- ttklabel(frame2, text="Format")
+  frame2.lab.3.1 <- ttklabel(frame2, text="Class")
+  frame2.lab.4.1 <- ttklabel(frame2, text="Function")
 
   frame2.ent.1.2 <- ttkentry(frame2, textvariable=name.var)
-  frame2.ent.2.2 <- ttkentry(frame2, textvariable=unit.var)
-  frame2.ent.3.2 <- ttkentry(frame2, textvariable=fmt.var)
-  frame2.ent.4.2 <- ttkentry(frame2, textvariable=class.var)
+  frame2.ent.2.2 <- ttkentry(frame2, textvariable=fmt.var)
+  frame2.ent.3.2 <- ttkentry(frame2, textvariable=class.var)
 
   fnt <- tkfont.create(family="Courier New", size=9)
-  frame2.txt.5.2 <- tktext(frame2, padx=2, pady=2, width=45, height=3,
+  frame2.txt.4.2 <- tktext(frame2, padx=2, pady=2, width=45, height=3,
                            undo=1, wrap="none", foreground="black",
                            background="#ebebe4", borderwidth=1, font=fnt)
 
-  frame2.but.3.3 <- ttkbutton(frame2, text="Edit", width=5,
+  frame2.but.2.3 <- ttkbutton(frame2, text="Edit", width=5,
                               command=CallFormat)
-  frame2.but.5.3 <- ttkbutton(frame2, text="Edit", width=5,
+  frame2.but.4.3 <- ttkbutton(frame2, text="Edit", width=5,
                               command=CallEditFunction)
 
   tkgrid(frame2.lab.1.1, frame2.ent.1.2, "x")
-  tkgrid(frame2.lab.2.1, frame2.ent.2.2, "x")
-  tkgrid(frame2.lab.3.1, frame2.ent.3.2, frame2.but.3.3)
-  tkgrid(frame2.lab.4.1, frame2.ent.4.2, "x")
-  tkgrid(frame2.lab.5.1, frame2.txt.5.2, frame2.but.5.3)
+  tkgrid(frame2.lab.2.1, frame2.ent.2.2, frame2.but.2.3)
+  tkgrid(frame2.lab.3.1, frame2.ent.3.2, "x")
+  tkgrid(frame2.lab.4.1, frame2.txt.4.2, frame2.but.4.3)
 
-  tkgrid.configure(frame2.lab.1.1, frame2.lab.2.1,
-                   frame2.lab.3.1, frame2.lab.4.1, sticky="w")
+  tkgrid.configure(frame2.lab.1.1, frame2.lab.2.1, frame2.lab.3.1, sticky="w")
 
-  tkgrid.configure(frame2.lab.5.1, sticky="ne")
+  tkgrid.configure(frame2.lab.4.1, sticky="ne")
 
-  tkgrid.configure(frame2.ent.1.2, frame2.ent.2.2,
-                   frame2.ent.3.2, frame2.ent.4.2,
+  tkgrid.configure(frame2.ent.1.2, frame2.ent.2.2, frame2.ent.3.2,
                    sticky="we", padx=2, pady=2)
 
-  tkgrid.configure(frame2.txt.5.2, padx=2, pady=2, sticky="nswe")
+  tkgrid.configure(frame2.txt.4.2, padx=2, pady=2, sticky="nswe")
 
-  tkgrid.configure(frame2.but.3.3, sticky="w")
-  tkgrid.configure(frame2.lab.5.1, pady=c(4, 0))
-  tkgrid.configure(frame2.but.5.3, sticky="nw", pady=c(1, 0))
+  tkgrid.configure(frame2.but.2.3, sticky="w")
+  tkgrid.configure(frame2.lab.4.1, pady=c(4, 0))
+  tkgrid.configure(frame2.but.4.3, sticky="nw", pady=c(1, 0))
 
   tkgrid.columnconfigure(frame2, 1, weight=1, minsize=25)
-  tkgrid.rowconfigure(frame2, 4, weight=1, minsize=25)
+  tkgrid.rowconfigure(frame2, 3, weight=1, minsize=25)
 
   # Frame 3, summary
 
@@ -648,9 +675,13 @@ ManageData <- function(cols, vars, parent=NULL) {
   tkgrid.rowconfigure(frame3, 0, weight=1, minsize=25)
 
   # Insert notebook and paned window
-
+  
   tkadd(pw, nb, weight=1)
   tkpack(pw, fill="both", expand="yes", padx=10, pady=c(10, 2))
+  
+  # Update Notebook
+  
+  UpdateNb()
 
   # Bind events
 
@@ -671,12 +702,9 @@ ManageData <- function(cols, vars, parent=NULL) {
   tkbind(frame1.lst, "<<ListboxSelect>>", UpdateNb)
 
   tkbind(frame2.ent.1.2, "<Return>", function() SetVarId())
-  tkbind(frame2.ent.2.2, "<Return>", function() SetVarId())
 
   # GUI control
 
-  UpdateNb()
-
   tkfocus(tt)
   tkgrab(tt)
   tkwait.variable(tt.done.var)
